@@ -27,6 +27,9 @@
 #include <string.h>
 #include <strings.h> /* compare */
 
+#include "gettext.h"
+#define _(String) gettext (String)
+
 #include "dinkc.h"
 #include "dinkc_bindings.h"
 #include "game_engine.h"
@@ -110,6 +113,7 @@ void decompress(FILE *in)
       ungetc(c, in);
     }
   
+  char* pc = cbuf + strlen(cbuf);
   for (;;)
     {
       /* Pop byte from stack or read byte from file */
@@ -124,7 +128,7 @@ void decompress(FILE *in)
 	  if ((c-128) >= nb_pairs)
 	    {
 	      fprintf(stderr, "decompress: invalid body: references non-existent pair\n");
-	      return;
+	      break;
 	    }
 	  stack[++top] = pairs[c-128][1];
 	  stack[++top] = pairs[c-128][0];
@@ -132,23 +136,26 @@ void decompress(FILE *in)
       else
 	{
 	  if (c == '\r') c = '\n';
-	  if (c == 9) c = ' ';
-	  strchar(cbuf,c);
+	  if (c == '\t') c = ' ';
+	  *pc = c;
+	  pc++;
 	}
     }
+  *pc = '\0';
 }
 
 void decompress_nocomp(FILE *in)
 {
   int c;
-  
-  /* Check for optional pair count and pair table */
+  char* pc = cbuf + strlen(cbuf);
   while ((c = getc(in)) != EOF)
     {
       if (c == '\r') c = '\n';
-      if (c == 9) c = ' ';
-      strchar(cbuf,c);
+      if (c == '\t') c = ' ';
+      *pc = c;
+      pc++;
     }
+  *pc = '\0';
 }
 
 
@@ -694,7 +701,7 @@ void decipher_string(char line[200], int script)
 	  else if (play.button[decipher_savegame] == 8)   replace("&buttoninfo", "Unused", line);
 	  else if (play.button[decipher_savegame] == 9)   replace("&buttoninfo", "Unused", line);
 	  else if (play.button[decipher_savegame] == 10)  replace("&buttoninfo", "Unused", line);
-	  else replace("&buttoninfo", "Error: not mapped", line);
+	  else replace("&buttoninfo", _("Error: not mapped"), line);
 	}
     }
 
@@ -704,19 +711,13 @@ void decipher_string(char line[200], int script)
       sprintf(crap, "save%d.dat", decipher_savegame);
       if (load_game_small(decipher_savegame, crab, &mytime) == 1)
 	{
-	  sprintf(line, "Slot %d - %d:%02d - %s",decipher_savegame, (mytime / 60),
+	  sprintf(line, _("Slot %d - %d:%02d - %s"), decipher_savegame, (mytime / 60),
 		  mytime - ((mytime / 60) * 60) , crab);
 	  //sprintf(line, "In Use");
 	}
       else
 	{
-#ifdef __GERMAN
-	  sprintf(line, "Slot %d - Ungebraucht",decipher_savegame);
-#endif
-	  
-#ifdef __ENGLISH
-	  sprintf(line, "Slot %d - Empty",decipher_savegame);
-#endif
+	  sprintf(line, _("Slot %d - Empty"), decipher_savegame);
 	}
     }
 }
@@ -848,47 +849,38 @@ void kill_all_scripts_for_real(void)
 
 /*bool*/int read_next_line(int script, char *line)
 {
+  if (rinfo[script] == NULL || rbuf == NULL)
+    {
+      Msg("  ERROR:  Tried to read script %d, it doesn't exist.", script);
+      return /*false*/0;
+    }
+
+  if (rinfo[script]->current >= rinfo[script]->end)
+    {
+      //at end of buffer
+      return /*false*/0;
+    }
+
+  line[0] = '\0';
+  char *pc = line;
+
   int k;
-        if (  (rinfo[script] == NULL) || (rbuf == NULL) )
-        {
+  for (k = rinfo[script]->current; k < rinfo[script]->end; k++)
+    {
+      *pc = rbuf[script][k];
+      pc++;
+      rinfo[script]->current++;
+      
+      if (rbuf[script][k] == '\n') // \r were replaced in decompress()
+	{
+	  *pc = '\0';
+	  return /*true*/1;
+	}
+    }
 
-                Msg("  ERROR:  Tried to read script %d, it doesn't exist.", script);
-                return(/*false*/0);
-        }
-
-        if (rinfo[script]->current >= rinfo[script]->end)
-        {
-                //at end of buffer
-                return(/*false*/0);
-        }
-
-        /*              if (rinfo[script]->current < -1);
-        {
-        //something errored out, why did it go negetive?
-        return(false);
-        }
-        */
-
-        strcpy(line, "");
-
-        for (k = rinfo[script]->current;  (k < rinfo[script]->end); k++)
-        {
-
-
-                //              Msg("..%d",k);
-                strchar(line, rbuf[script][k]);
-                rinfo[script]->current++;
-
-                if (  (rbuf[script][k] == '\n') || (rbuf[script][k] == '\r')  )
-                {
-                        return(/*true*/1);
-                }
-
-                if (rinfo[script]->current >= rinfo[script]->end) return(/*false*/0);
-
-        }
-
-        return(/*false*/0);
+  //at end of buffer
+  *pc = '\0';
+  return /*false*/0;
 }
 
 /**
@@ -1085,70 +1077,43 @@ void run_script(int script)
       Msg("Error:  Tried to run a script that doesn't exist in memory.  Nice work.");
     }
 
+  int doelse_once = 0;
   while (read_next_line(script, line))
     {
-      while(1)
+      while (1)
 	{
 	  strip_beginning_spaces(line);
-	  if (compare(line, "\n"))
+	  if (strcmp(line, "\n") == 0)
 	    break;
 
-	  result = process_line(script, line, /*false*/0);
-
-	  if (result == 3)
+	  
+	  int doelse = 0;
+	  if (doelse_once == 1)
 	    {
-	    redo:
-	      read_next_line(script, line);
-	    crappa:
-	      strip_beginning_spaces(line);
-	      if (compare(line, "\n")) goto redo;
-	      if (compare(line, "\\\\")) goto redo;
-	      //           Msg("processing %s knowing we are going to skip it...", line);
-	      result = process_line(script,line, /*true*/1);
+	      doelse = 1;
+	      doelse_once = 0;
+	    }
+	  result = process_line(script, line, doelse);
+	  
+
+	  if (result == DCPS_DOELSE_ONCE)
+	    {
+	      doelse_once = 1;
+	      /* now process the rest of the line */
 	    }
 
-	  if (result == 5)
-	    goto crappa;
-
-	  if (result == 3)
-	      goto redo;
-
-	  if (result == 2)
+	  if (result == DCPS_YIELD)
 	    {
+	      /* Quit script: */
 	      if (debug_mode)
 		Msg("giving script the boot");
-	      //quit script
 	      return;
 	    }
-
-	  if (result == 0)
+	  
+	  if (result == DCPS_GOTO_NEXTLINE)
 	    break;
 
-	  if (result == 4)
-	    {
-	      //       Msg("Was sent %s, length %d", line, strlen(line));
-	      if (strlen(line) < 2)
-		{
-		redo2:
-		  read_next_line(script, line);
-		  strip_beginning_spaces(line);
-		  //Msg("Comparing to %s.", line);
-		  if (compare(line, "\n"))
-		    goto redo2;
-		  if (compare(line, "\\\\"))
-		    goto redo2;
-		}
-	      result = process_line(script,line, /*true*/1);
-	    }
-
-	  if (result == 2)
-	    {
-	      if (debug_mode)
-		Msg("giving script the boot");
-	      //quit script
-	      return;
-	    }
-	  if (result == 0) break;
+	  /* else result == DCPS_CONTINUE */
 	}
     }
 
@@ -1159,64 +1124,44 @@ void run_script(int script)
     }
 }
 
-void get_word(char line[300], int word, char *crap)
+/**
+ * Copy the word number 'word' present in 'line' to the 'result'
+ * string. Words are separated by one or more spaces and count from 1
+ * (i.e. not 0).
+ */
+void get_word(char line[300], int word, char *result)
 {
-        int cur = 0;
-        int k;
+  int cur_word = 1;
+  result[0] = '\0';
 
-        /*bool*/int space_mode = /*false*/0;
-        char save_word[100];
-        save_word[0] = 0;
-
-        for (k = 0; k < strlen(line); k++)
-        {
-
-                if (space_mode == /*true*/1)
-                {
-                        if (line[k] != ' ')
-                        {
-                                space_mode = /*false*/0;
-                                strcpy(save_word, "");
-
-                        }
-                }
-
-
-
-                if (space_mode == /*false*/0)
-                {
-                        if (line[k] == ' ')
-                        {
-                                cur++;
-                                if (word == cur) goto done;
-                                space_mode = /*true*/1;
-                                strcpy(save_word, "");
-
-                                goto dooba;
-                        } else
-                        {
-                                strchar(save_word, line[k]);
-
-                        }
-                }
-
-
-dooba:;
-
-        }
-
-        if (space_mode == /*false*/0)
-        {
-
-                if (cur+1 != word) strcpy(save_word, "");
-        }
-
-
-done:
-
-        strcpy(crap, save_word);
-
-        //Msg("word %d of %s is %s.", word, line, crap);
+  /* find word */
+  char* pc = line;
+  while (*pc != '\0')
+    {
+      if (cur_word == word)
+	break;
+      if (*pc == ' ')
+	{
+	  cur_word++;
+	  while(*pc == ' ' && *pc != '\0')
+	    pc++;
+	}
+      else
+	{
+	  while(*pc != ' ' && *pc != '\0')
+	    pc++;
+	}
+    }
+  /* copy word - either we're on the right word and will copy it,
+     either we're at the end of string and will copy an empty word */
+  char* pcr = result;
+  while(*pc != '\0' && *pc != ' ')
+    {
+      *pcr = *pc;
+      pcr++;
+      pc++;
+    }
+  *pcr = '\0';
 }
 
 int var_exists(char name[20], int scope)
@@ -1572,3 +1517,13 @@ int var_figure(char h[200], int script)
                 strcpy(line, hold);
 
         }
+
+void dinkc_init()
+{
+  dinkc_bindings_init();
+}
+
+void dinkc_quit()
+{
+  dinkc_bindings_quit();
+}
