@@ -1358,6 +1358,7 @@ void dc_sp(int script, int* yield, int* preturnint,
   if (last_sprite_created == 1)
     Msg("warning - you can't call SP() from a screen-ref,"
 	" no sprites have been created yet.");
+  *preturnint = 0; /* not found */
 }
 
 void dc_is_script_attached(int script, int* yield, int* preturnint,
@@ -1380,6 +1381,7 @@ void dc_get_sprite_with_this_brain(int script, int* yield, int* preturnint,
 	  return;
 	}
     }
+  *preturnint = 0; /* not found */
 }
 
 void dc_get_rand_sprite_with_this_brain(int script, int* yield, int* preturnint,
@@ -1414,6 +1416,7 @@ void dc_get_rand_sprite_with_this_brain(int script, int* yield, int* preturnint,
 	    }
 	}
     }
+  *preturnint = 0; /* not found */
 }
 
 void dc_set_button(int script, int* yield, int* preturnint,
@@ -1829,6 +1832,7 @@ void dc_get_next_sprite_with_this_brain(int script, int* yield, int* preturnint,
 	  }
     }
   Msg ("Ok, sprite with brain %d is 0", brain);
+  *preturnint = 0; /* not found */
 }
 
 void dc_set_smooth_follow(int script, int* yield, int* preturnint, int smooth_p)
@@ -1982,6 +1986,9 @@ void dinkc_bindings_init()
 			     dinkc_bindings_hasher, dinkc_bindings_comparator,
 			     free);
 
+
+  /* funcname, params, badparams_dcps, badparams_returnint_p, badparams_returnint */
+
   DCBD_ADD(sp_active,                 {1,1,0,0,0,0,0,0,0,0}, DCPS_GOTO_NEXTLINE, 1, -1);
   DCBD_ADD(sp_attack_hit_sound,       {1,1,0,0,0,0,0,0,0,0}, DCPS_GOTO_NEXTLINE, 1, -1);
   DCBD_ADD(sp_attack_hit_sound_speed, {1,1,0,0,0,0,0,0,0,0}, DCPS_GOTO_NEXTLINE, 1, -1);
