@@ -73,7 +73,7 @@ struct sprite_placement
   char talk[13];   /* unused */
   int speed, base_walk, base_idle, base_attack, base_hit, timer, que;
   int hard;
-  rect alt;
+  rect alt; /* trim left/top/right/bottom */
   int prop;
   int warp_map;
   int warp_x;
@@ -103,9 +103,9 @@ struct small_map
 
 struct talk_struct
 {
-  char line[21][101];
-  int line_return[21];
-  char buffer[3000];
+  char line[21][101];  /* dialog choices */
+  int line_return[21]; /* return this number if chosen */
+  char buffer[3000];   /* title */
   int cur;
   int last;
   /*bool*/int active;
@@ -366,11 +366,12 @@ extern void init_scripts(void);
 
 
 /* Used by dinkc_bindings.c only */
+enum item_type { ITEM_REGULAR, ITEM_MAGIC };
 extern void clear_talk(void);
-extern void add_item(char name[10], int mseq, int mframe, /*bool*/int magic);
+extern void add_item(char name[10], int mseq, int mframe, enum item_type type);
 extern void kill_cur_item_script( char name[20]);
 extern void kill_cur_magic_script( char name[20]);
-extern void show_bmp(char name[80], int showdot, int reserved, int script);
+extern void show_bmp(char name[80], int showdot, int script);
 extern void copy_bmp( char name[80]);
 extern void kill_cur_item( void );
 extern void kill_cur_magic( void );
