@@ -24,13 +24,14 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h> /* putenv */
+#include <string.h>
+#include <math.h>
+
 #include "SDL.h"
 #include "SDL_image.h"
 #include "SDL_rotozoom.h"
 
-#include <string.h>
-#include <math.h>
-
 #include "freedink_xpm.h"
 #include "io_util.h"
 #include "gfx.h"
@@ -186,6 +187,11 @@ int gfx_init(enum gfx_windowed_state windowed)
       init_set_error_msg("Unable to set 640x480 video: %s\n", SDL_GetError());
       return -1;
     }
+  char buf[1024];
+  if (SDL_VideoDriverName(buf, 1024) != NULL)
+    printf("INFO: Video driver is '%s'\n", buf);
+  else
+    printf("INFO: Unable to determine video driver name\n");
   if (GFX_lpDDSBack->flags & SDL_HWSURFACE)
     printf("INFO: Using hardware video mode.\n");
   else
